@@ -1,11 +1,11 @@
-import logging
+from squad_client import logging
 from squad_client.core.command import SquadClientCommand
 
 
 INCLUDE_TESTS_CMD = True
 
 
-logger = logging.getLogger()
+logger = logging.getLogger(__name__)
 
 
 try:
