@@ -39,8 +39,8 @@ class SquadObject:
 
     def __init__(self, _id=None):
         if _id:
-            self.endpoint += str(_id)
-            self.__fetch__()
+            endpoint = '%s%d' % (self.endpoint, _id)
+            self.__fetch__(endpoint=endpoint)
 
     @classmethod
     def get_type(cls, _type):
@@ -99,7 +99,7 @@ class SquadObject:
         """
 
         if klass is None:
-            response = SquadApi.get(self.endpoint)
+            response = SquadApi.get(endpoint or self.endpoint)
             result = response.json()
             self.__fill_object__(result)
             return
@@ -440,11 +440,11 @@ class ProjectBasicSettings(SquadObject):
 class Build(SquadObject):
 
     endpoint = '/api/builds/'
-    attrs = ['url', 'id', 'testjobs', 'finished',
+    attrs = ['url', 'id', 'finished',
              'version', 'created_at', 'datetime', 'patch_id', 'keep_data', 'project',
              'patch_source', 'patch_baseline']
 
-    def testruns(self, count=ALL, bucket_suites=False, **filters):
+    def testruns(self, count=ALL, bucket_suites=False, prefetch_metadata=False, **filters):
         filters.update({'build': self.id})
         testruns = self.__fetch__(TestRun, filters, count)
 
@@ -452,8 +452,30 @@ class Build(SquadObject):
             for _id in testruns.keys():
                 testruns[_id].bucket_metric_and_test_suites()
 
+        if prefetch_metadata:
+            endpoint = '%s%d/metadata_by_testrun' % (self.endpoint, self.id)
+            response = SquadApi.get(endpoint)
+            if response.text != "None":
+                metadata_by_testrun = response.json()
+                for testrun_id in testruns.keys():
+                    testruns[testrun_id].metadata = metadata_by_testrun[str(testrun_id)]
+
         return testruns
 
+    # this _ testjobs__ attribute is for getting the TestJob objects for this Build
+    __testjobs__ = None
+
+    def testjobs(self, count=ALL, **filters):
+        if self.__testjobs__ is None:
+            self.__testjobs__ = {}
+
+        filters['count'] = count
+        filters_str = str(OrderedDict(filters))
+        if self.__testjobs__.get(filters_str) is None:
+            endpoint = '%s%d/testjobs/' % (self.endpoint, self.id)
+            self.__testjobs__[filters_str] = self.__fetch__(TestJob, filters, count, endpoint=endpoint)
+        return self.__testjobs__[filters_str]
+
     __tests__ = None
 
     def tests(self, count=ALL, **filters):
@@ -533,7 +555,7 @@ class TestJob(SquadObject):
              'submitted_at', 'fetched_at', 'submitted', 'fetched', 'fetch_attempts',
              'last_fetch_attempt', 'failure', 'can_resubmit', 'resubmitted_count',
              'job_id', 'job_status', 'backend', 'testrun', 'target', 'target_build',
-             'parent_job']
+             'parent_job', 'started_at', 'ended_at']
 
     def submit(self):
         squad = Squad()
